==> apiconnect-cli-util-3.0.3.tgz: package/lib/util/context.js <==
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-util
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
/*eslint brace-style: 0, max-len: 0*/

var _ = require('lodash');
var apicConfig = require('apiconnect-cli-config');
var Catalogs = require('../catalogs/catalogs');
var Orgs = require('../orgs/organizations');
var Consts = require('./consts');
var debug = require('debug')('apiconnect-cli-util:util:context');

/**
 * Defines a context in which a request is invoked. The context is defined by server, username, password and org(s)|catalog(s)
 * that is associated to an user.
 *
 * @constructor
 */

function Context(opts) {
  initialize(this);
  this.set(opts);
}
/**
 * Set the current session context in which a request to a backend rest api is invoked.
 *
 * @param opts {object|} optional object contains properties (like username, password, server, organization, catalog)
 *             in which request gets invoked.
 */
Context.prototype.set = function(opts) {
  if (!opts) {
    return;
  }
  var self = this;

   //catalogs and catalog should be the same as well as all organizations and organization
  if (opts.orgs) {
    opts.organizations = opts.orgs;
  }
  if (opts.organization) {
    opts.organizations = opts.organization;
  }
  if (opts.catalog) {
    opts.catalogs = opts.catalog;
  }
  _.keys(opts).forEach(function(key) {
    self.ctx[key] = opts[key];
  });
};


Context.prototype.get = function() {
  return this.ctx;
};

/**
 * Create catalog context  - essential it will fetch the catalogs in which a request needs be executed
 * The logic is:
 *  if --all-organizations is true then:
 *     - if --all-catalogs true fetch all catalogs
 *     - if --catalog return only all the catalogs that matches that name accross all organizations
 *
 * if --all-catalogs is true then
 *    - return all catalogs within the set organization
 * if --organization then
 *    - if --all-catalogs return all catalogs within than organization
 *    - if --catalog return catalog within the organization (or error if not found)
 *
 * if --catalog then
 *    return catalog within set organization
 *
 * @param cb {Function (err, rsp)}  callback function that gets invoked when an error or the context has been created
 *           rsp {object} format of the response is: { "<orgName>": [Array of Catalog] }
 */
Context.prototype.createCatalogContext = function(cb) {
  var self = this;
  var catalogs = new Catalogs();
  catalogs.list(function(err, result) {
    if (err) {
      cb(err);
    }
    else {
      var response = catalogs.filter(self.get());
      cb(null, response);
    }
  });
};
/**
 * Create org context in which a command is executed.
 *
 * @param cb
 */
Context.prototype.createOrgContext = function(cb) {
  var self = this;
  if (self.ctx.allOrganizations) {
    Orgs.list(function(err, rsp, body) {
      if (err) {
        return cb(err, null);
      }
      body = typeof body === 'string' ? JSON.parse(body) : body;
      cb(err, body);
    });
  }
  else {
    cb(null, [ { name: self.ctx.organization } ]);
  }
};

function initialize(ctx) {
  debug('initialize');
  ctx.ctx = {};
  ctx.session = {};
  var cfg = apicConfig.loadConfig();
  var obj = cfg.get(Consts.catalog);
  if (!obj || !obj[Consts.catalog]) {
    obj = { data: {} };//empty object
  }
  else {
    obj = obj[Consts.catalog];
    if (!obj.data) {
      obj.data = {};
    }
  }
  ctx.set(obj.data);
  ctx.ctx.server = obj.hostname;
  ctx.ctx.port = obj.port;//port may not be defined??
  ctx.ctx.auth = obj.auth;//auth may not be defined??
  debug('initialize complete: %j', ctx);
}
/**
 * Reset the context
 */
Context.prototype.reset = function() {
  initialize(this);
};

module.exports.Context = new Context({});

==> apiconnect-cli-util-5.0.1.tgz: package/lib/util/context.js <==
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-util
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
/*eslint brace-style: 0, max-len: 0*/

var Consts = require('./consts');
var Orgs = require('../orgs/organizations');
var _ = require('lodash');
var apicConfig = require('apiconnect-config');
var debug = require('debug')('apiconnect-cli-util:util:context');

/**
 * Defines a context in which a request is invoked. The context is defined by server, username, password and org(s)|catalog(s)
 * that is associated to an user.
 *
 * @constructor
 */

function Context(opts) {
  initialize(this);
  this.set(opts);
}
/**
 * Set the current session context in which a request to a backend rest api is invoked.
 *
 * @param opts {object|} optional object contains properties (like username, password, server, organization, catalog)
 *             in which request gets invoked.
 */
Context.prototype.set = function(opts) {
  if (!opts) {
    return;
  }
  var self = this;

   //catalogs and catalog should be the same as well as all organizations and organization
  if (opts.orgs) {
    opts.organizations = opts.orgs;
  }
  if (opts.organization) {
    opts.organizations = opts.organization;
  }
  if (opts.catalog) {
    opts.catalogs = opts.catalog;
  }
  _.keys(opts).forEach(function(key) {
    self.ctx[key] = opts[key];
  });
};


Context.prototype.get = function() {
  return this.ctx;
};

/**
 * Create catalog context  - essential it will fetch the catalogs in which a request needs be executed
 * The logic is:
 *  if --all-organizations is true then:
 *     - if --all-catalogs true fetch all catalogs
 *     - if --catalog return only all the catalogs that matches that name accross all organizations
 *
 * if --all-catalogs is true then
 *    - return all catalogs within the set organization
 * if --organization then
 *    - if --all-catalogs return all catalogs within than organization
 *    - if --catalog return catalog within the organization (or error if not found)
 *
 * if --catalog then
 *    return catalog within set organization
 *
 * @param cb {Function (err, rsp)}  callback function that gets invoked when an error or the context has been created
 *           rsp {object} format of the response is: { "<orgName>": [Array of Catalog] }
 */
Context.prototype.createCatalogContext = function(cb) {

  var self = this;

  // required is moved here due to a bug in dependency which made Catalogs = {} if it's in top
  var Catalogs = require('../catalogs/catalogs');
  var catalogs = new Catalogs();
  catalogs.list(function(err, result) {
    if (err) {
      cb(err);
    }
    else {
      var response = catalogs.filter(self.get());
      cb(null, response);
    }
  });
};
/**
 * Create org context in which a command is executed.
 *
 * @param cb
 */
Context.prototype.createOrgContext = function(cb) {
  var self = this;
  if (self.ctx.allOrganizations) {
    Orgs.list(function(err, rsp, body) {
      if (err) {
        return cb(err, null);
      }
      body = typeof body === 'string' ? JSON.parse(body) : body;
      cb(err, body);
    });
  }
  else {
    cb(null, [ { name: self.ctx.organization } ]);
  }
};

function initialize(ctx) {
  debug('initialize');
  ctx.ctx = {};
  ctx.session = {};
  var cfg = apicConfig.loadConfig();
  var obj = cfg.get(Consts.catalog);
  if (!obj || !obj[Consts.catalog]) {
    obj = { data: {} };//empty object
  }
  else {
    obj = obj[Consts.catalog];
    if (!obj.data) {
      obj.data = {};
    }
  }
  ctx.set(obj.data);
  ctx.ctx.server = obj.hostname;
  ctx.ctx.port = obj.port;//port may not be defined??
  ctx.ctx.auth = obj.auth;//auth may not be defined??
  debug('initialize complete: %j', ctx);
}
/**
 * Reset the context
 */
Context.prototype.reset = function() {
  initialize(this);
};

module.exports.Context = new Context({});
